@@ -47,6 +47,7 @@ class Journal(metaclass=PoolMeta):
                         ('origin.journal.id', '=', journal.id,
                             'account.payment'),
                         ('state', '=', 'draft'),
+                        ('company', '=', Transaction().context.get('company')),
                         ]))
         Move.post(moves)
 
@@ -57,7 +58,7 @@ class Payment(metaclass=PoolMeta):
         'account.account', "Account", ondelete='RESTRICT',
         domain=[
             ('company', '=', Eval('company', -1)),
-            ('kind', 'in', ['receivable', 'payable', 'deposit']),
+            ('type.statement', '=', 'balance'),
             ['OR',
                 ('second_currency', '=', Eval('currency', None)),
                 [
@@ -168,7 +169,7 @@ class Payment(metaclass=PoolMeta):
             local_amount = self.amount
 
         move = Move(journal=self.journal.clearing_journal, origin=self,
-            date=date, period=period, company=self.company)
+            date=date, period=period)
         line = Line()
         if self.kind == 'payable':
             line.debit, line.credit = local_amount, 0
